package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Oct 24, 2025
License: LGPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Diff returns the elements of a which are not in b.
Set is a wrapper over map.
I don't want to depend on a set library just for this.
func (s Set[X]) Members() []X
Source Files
¶
Click to show internal directories.
Click to hide internal directories.